==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/ExtendedKeyUsage.h <==
// public class gnu.java.security.x509.ext.ExtendedKeyUsage

// class file dependencies
// @dep_class ad0bfde46fcdcdcf gnu_java_security_x509_ext_ExtendedKeyUsage
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_ExtendedKeyUsage_H_
#define _JC_gnu_java_security_x509_ext_ExtendedKeyUsage_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object;

typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24ExtendedKeyUsage;
};
extern _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$getPurposeIds$454537f08ea8e388(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method_info$getPurposeIds$454537f08ea8e388;
extern _jc_method _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods {
	struct _jc_object	*(*getPurposeIds$454537f08ea8e388)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods	gnu_java_security_x509_ext_ExtendedKeyUsage;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs {
	struct _jc_object	*purposeIds;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs {
    _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs	gnu_java_security_x509_ext_ExtendedKeyUsage;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs	gnu_java_security_x509_ext_ExtendedKeyUsage;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object {
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_ExtendedKeyUsage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_ExtendedKeyUsage_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/ExtendedKeyUsage.h <==
// public class gnu.java.security.x509.ext.ExtendedKeyUsage

// class file dependencies
// @dep_class ad0bfde46fcdcdcf gnu_java_security_x509_ext_ExtendedKeyUsage
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_ExtendedKeyUsage_H_
#define _JC_gnu_java_security_x509_ext_ExtendedKeyUsage_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object;

typedef struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24ExtendedKeyUsage;
};
extern _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$fields_struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$getPurposeIds$454537f08ea8e388(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method_info$getPurposeIds$454537f08ea8e388;
extern _jc_method _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods {
	struct _jc_object	*(*getPurposeIds$454537f08ea8e388)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vmethods	gnu_java_security_x509_ext_ExtendedKeyUsage;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs {
	struct _jc_object	*purposeIds;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs {
    _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_refs	gnu_java_security_x509_ext_ExtendedKeyUsage;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$sub_nonrefs	gnu_java_security_x509_ext_ExtendedKeyUsage;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$object {
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_ExtendedKeyUsage$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$vtype _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_ExtendedKeyUsage, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_ExtendedKeyUsage$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_ExtendedKeyUsage_H_ */
